window.cockpit_po = {
 "": {
  "plural-forms": (n) => 0,
  "language": "lo",
  "language-direction": "ltr"
 },
 "$0 GiB": [
  null,
  "$0 GiB"
 ],
 "$0 day": [
  null,
  "$0 ມື້"
 ],
 "$0 error": [
  null,
  "ຂໍ້ຜິດພາດ $0"
 ],
 "$0 exited with code $1": [
  null,
  "$0 ອອກດ້ວຍລະຫັດ $1"
 ],
 "$0 failed": [
  null,
  "$0 ຫຼົ້ມເຫຼວ"
 ],
 "$0 hour": [
  null,
  "$0 ຊົ່ວໂມງ"
 ],
 "$0 is not available from any repository.": [
  null,
  "$0 ບໍ່ມີໃຫ້ໃຊ້ຈາກຄັງຊອບແວໃດໆ."
 ],
 "$0 key changed": [
  null,
  "ຄີ $0 ປ່ຽນແປງແລ້ວ"
 ],
 "$0 killed with signal $1": [
  null,
  "$0 ຖືກຢຸດດ້ວຍສັນຍານ $1"
 ],
 "$0 minute": [
  null,
  "$0 ນາທີ"
 ],
 "$0 month": [
  null,
  "$0 ເດືອນ"
 ],
 "$0 week": [
  null,
  "$0 ອາທິດ"
 ],
 "$0 will be installed.": [
  null,
  "$0 ຈະຖືກຕິດຕັ້ງ."
 ],
 "$0 year": [
  null,
  "$0 ປີ"
 ],
 "1 day": [
  null,
  "1 ມື້"
 ],
 "1 hour": [
  null,
  "1 ຊົ່ວໂມງ"
 ],
 "1 minute": [
  null,
  "1 ນາທີ"
 ],
 "1 week": [
  null,
  "1 ອາທິດ"
 ],
 "20 minutes": [
  null,
  "20 ນາທີ"
 ],
 "40 minutes": [
  null,
  "40 ນາທີ"
 ],
 "5 minutes": [
  null,
  "5 ນາທີ"
 ],
 "6 hours": [
  null,
  "6 ຊົ່ວໂມງ"
 ],
 "60 minutes": [
  null,
  "60 ນາທີ"
 ],
 "A compatible version of Cockpit is not installed on $0.": [
  null,
  "ເວີຊັນຂອງ Cockpit ທີ່ເຂົ້າກັນໄດ້ບໍ່ໄດ້ຖືກຕິດຕັ້ງຢູ່ໃນ $0."
 ],
 "A modern browser is required for security, reliability, and performance.": [
  null,
  "ຕ້ອງການບຣາວເຊີທີ່ທັນສະໄໝເພື່ອຄວາມປອດໄພ, ຄວາມໜ້າເຊື່ອຖື ແລະ ປະສິດທິພາບ."
 ],
 "A new SSH key at $0 will be created for $1 on $2 and it will be added to the $3 file of $4 on $5.": [
  null,
  "SSH ຄີໃໝ່ຢູ່ $0 ຈະຖືກສ້າງຂຶ້ນສຳລັບ $1 ຢູ່ $2 ແລະ ມັນຈະຖືກເພີ່ມເຂົ້າໃນໄຟລ໌ $3 ຂອງ $4 ຢູ່ $5."
 ],
 "Absent": [
  null,
  "ບໍ່ມີຢູ່"
 ],
 "Accept key and log in": [
  null,
  "ຍອມຮັບຄີ ແລະ ເຂົ້າລະບົບ"
 ],
 "Acceptable password": [
  null,
  "ລະຫັດຜ່ານທີ່ຍອມຮັບໄດ້"
 ],
 "Add $0": [
  null,
  "ເພີ່ມ $0"
 ],
 "Additional packages:": [
  null,
  "ແພັກເກດເພີ່ມເຕີມ:"
 ],
 "Administration with Cockpit Web Console": [
  null,
  "ການບໍລິຫານດ້ວຍ Cockpit Web Console"
 ],
 "Administrative access": [
  null,
  "ສິດການບໍລິຫານ"
 ],
 "Advanced TCA": [
  null,
  "Advanced TCA"
 ],
 "All-in-one": [
  null,
  "ທັງໝົດໃນອັນດຽວ"
 ],
 "Ansible": [
  null,
  "Ansible"
 ],
 "Ansible roles documentation": [
  null,
  "ເອກະສານ Ansible roles"
 ],
 "Authenticate": [
  null,
  "ຢືນຢັນຕົວຕົນ"
 ],
 "Authentication": [
  null,
  "ການຢືນຢັນຕົວຕົນ"
 ],
 "Authentication failed": [
  null,
  "ການຢືນຢັນຕົວຕົນຫຼົ້ມເຫຼວ"
 ],
 "Authentication is required to perform privileged tasks with the Cockpit Web Console": [
  null,
  "ຕ້ອງມີການຢືນຢັນຕົວຕົນເພື່ອດຳເນີນການວຽກທີ່ມີສິດພິເສດດ້ວຍ Cockpit Web Console"
 ],
 "Authorize SSH key": [
  null,
  "ອະນຸຍາດ SSH ຄີ"
 ],
 "Automatically using NTP": [
  null,
  "ໃຊ້ອັດຕະໂນມັດໂດຍ NTP"
 ],
 "Automatically using additional NTP servers": [
  null,
  "ໃຊ້ອັດຕະໂນມັດໂດຍໃຊ້ເຊີເວີ NTP ເພີ່ມເຕີມ"
 ],
 "Automatically using specific NTP servers": [
  null,
  "ໃຊ້ອັດຕະໂນມັດໂດຍໃຊ້ເຊີເວີ NTP ທີ່ລະບຸ"
 ],
 "Automation script": [
  null,
  "ສະຄຣິບອັດຕະໂນມັດ"
 ],
 "Blade": [
  null,
  "Blade"
 ],
 "Blade enclosure": [
  null,
  "Blade enclosure"
 ],
 "Bus expansion chassis": [
  null,
  "Bus expansion chassis"
 ],
 "Bypass browser check": [
  null,
  "ຂ້າມການກວດສອບບຣາວເຊີ"
 ],
 "Cancel": [
  null,
  "ຍົກເລີກ"
 ],
 "Cannot forward login credentials": [
  null,
  "ບໍ່ສາມາດສົ່ງຕໍ່ຂໍ້ມູນການເຂົ້າລະບົບໄດ້"
 ],
 "Cannot schedule event in the past": [
  null,
  "ບໍ່ສາມາດຕັ້ງເວລາໃນອະດີດໄດ້"
 ],
 "Change": [
  null,
  "ປ່ຽນ"
 ],
 "Change system time": [
  null,
  "ປ່ຽນເວລາຂອງລະບົບ"
 ],
 "Changed keys are often the result of an operating system reinstallation. However, an unexpected change may indicate a third-party attempt to intercept your connection.": [
  null,
  "ຄີທີ່ປ່ຽນແປງມັກຈະເກີດຈາກການຕິດຕັ້ງລະບົບປະຕິບັດການໃໝ່. ຢ່າງໃດກໍຕາມ, ການປ່ຽນແປງທີ່ບໍ່ຄາດຄິດອາດໝາຍເຖິງການພະຍາຍາມແຊກແຊງການເຊື່ອມຕໍ່ຂອງທ່ານຈາກບຸກຄົນທີສາມ."
 ],
 "Checking installed software": [
  null,
  "ກຳລັງກວດສອບຊອບແວທີ່ຕິດຕັ້ງແລ້ວ"
 ],
 "Clear input value": [
  null,
  "ລຶບຄ່າທີ່ປ້ອນເຂົ້າ"
 ],
 "Close": [
  null,
  "ປິດ"
 ],
 "Cockpit": [
  null,
  "Cockpit"
 ],
 "Cockpit authentication is configured incorrectly.": [
  null,
  "ການຢືນຢັນຕົວຕົນຂອງ Cockpit ຖືກຕັ້ງຄ່າບໍ່ຖືກຕ້ອງ."
 ],
 "Cockpit configuration of NetworkManager and Firewalld": [
  null,
  "ການຕັ້ງຄ່າ NetworkManager ແລະ Firewalld ຂອງ Cockpit"
 ],
 "Cockpit could not contact the given host.": [
  null,
  "Cockpit ບໍ່ສາມາດຕິດຕໍ່ກັບໂຮສຕ໌ທີ່ລະບຸໄດ້."
 ],
 "Cockpit is a server manager that makes it easy to administer your Linux servers via a web browser. Jumping between the terminal and the web tool is no problem. A service started via Cockpit can be stopped via the terminal. Likewise, if an error occurs in the terminal, it can be seen in the Cockpit journal interface.": [
  null,
  "Cockpit ແມ່ນລະບົບຈັດການເຊີເວີທີ່ຊ່ວຍໃຫ້ການບໍລິຫານເຊີເວີ Linux ຂອງທ່ານຜ່ານເວັບບຣາວເຊີເປັນເລື່ອງງ່າຍ. ທ່ານສາມາດສະຫຼັບການເຮັດວຽກລະຫວ່າງເທີມິນໍ ແລະ ເຄື່ອງມືເວັບໄດ້ຢ່າງສະດວກ."
 ],
 "Cockpit is not compatible with the software on the system.": [
  null,
  "Cockpit ບໍ່ເຂົ້າກັນໄດ້ກັບຊອບແວໃນລະບົບ."
 ],
 "Cockpit is not installed": [
  null,
  "Cockpit ບໍ່ໄດ້ຖືກຕິດຕັ້ງ"
 ],
 "Cockpit is not installed on the system.": [
  null,
  "Cockpit ບໍ່ໄດ້ຖືກຕິດຕັ້ງຢູ່ໃນລະບົບ."
 ],
 "Cockpit is perfect for new sysadmins, allowing them to easily perform simple tasks such as storage administration, inspecting journals and starting and stopping services. You can monitor and administer several servers at the same time. Just add them with a single click and your machines will look after its buddies.": [
  null,
  "Cockpit ແມ່ນເໝາະສົມສຳລັບຜູ້ດູແລລະບົບໃໝ່, ຊ່ວຍໃຫ້ດຳເນີນວຽກງ່າຍໆ ເຊັ່ນ ການຈັດການບ່ອນເກັບຂໍ້ມູນ, ກວດສອບລັອກ ແລະ ການຈັດການບໍລິການຕ່າງໆ."
 ],
 "Cockpit might not render correctly in your browser": [
  null,
  "Cockpit ອາດຈະສະແດງຜົນບໍ່ຖືກຕ້ອງໃນບຣາວເຊີຂອງທ່ານ"
 ],
 "Collect and package diagnostic and support data": [
  null,
  "ເກັບກຳ ແລະ ລວມແພັກເກດຂໍ້ມູນການວິເຄາະ ແລະ ການຊ່ວຍເຫຼືອ"
 ],
 "Collect kernel crash dumps": [
  null,
  "ເກັບກຳຂໍ້ມູນ kernel crash dumps"
 ],
 "Compact PCI": [
  null,
  "Compact PCI"
 ],
 "Confirm key password": [
  null,
  "ຢືນຢັນລະຫັດຜ່ານຂອງຄີ"
 ],
 "Connect to": [
  null,
  "ເຊື່ອມຕໍ່ຫາ"
 ],
 "Connect to:": [
  null,
  "ເຊື່ອມຕໍ່ຫາ:"
 ],
 "Connection has timed out.": [
  null,
  "ການເຊື່ອມຕໍ່ໝົດເວລາ."
 ],
 "Convertible": [
  null,
  "Convertible"
 ],
 "Copied": [
  null,
  "ກັອບປີ້ແລ້ວ"
 ],
 "Copy": [
  null,
  "ກັອບປີ້"
 ],
 "Copy to clipboard": [
  null,
  "ກັອບປີ້ໄວ້ໃນຄລິບບອດ"
 ],
 "Create $0": [
  null,
  "ສ້າງ $0"
 ],
 "Create a new SSH key and authorize it": [
  null,
  "ສ້າງ SSH ຄີໃໝ່ ແລະ ອະນຸຍາດມັນ"
 ],
 "Create new task file with this content.": [
  null,
  "ສ້າງໄຟລ໌ວຽກໃໝ່ດ້ວຍເນື້ອຫານີ້."
 ],
 "Ctrl+Insert": [
  null,
  "Ctrl+Insert"
 ],
 "Delay": [
  null,
  "ການໜ່ວງເວລາ"
 ],
 "Desktop": [
  null,
  "ເດດທອບ"
 ],
 "Detachable": [
  null,
  "ຖອດອອກໄດ້"
 ],
 "Diagnostic reports": [
  null,
  "ລາຍງານການກວດສອບບັນຫາ"
 ],
 "Docking station": [
  null,
  "ດັອກກິງສະເຕຊັນ"
 ],
 "Download a new browser for free": [
  null,
  "ດາວໂຫຼດບຣາວເຊີໃໝ່ໄດ້ຟຣີ"
 ],
 "Downloading $0": [
  null,
  "ກຳລັງດາວໂຫຼດ $0"
 ],
 "Dual rank": [
  null,
  "Dual rank"
 ],
 "Embedded PC": [
  null,
  "ຄອມພິວເຕີຝັງຕົວ"
 ],
 "Error during initialization": [
  null,
  "ເກີດຂໍ້ຜິດພາດລະຫວ່າງການເລີ່ມຕົ້ນ"
 ],
 "Excellent password": [
  null,
  "ລະຫັດຜ່ານດີເລີດ"
 ],
 "Expansion chassis": [
  null,
  "Expansion chassis"
 ],
 "Failed": [
  null,
  "ຫຼົ້ມເຫຼວ"
 ],
 "Failed to change password": [
  null,
  "ບໍ່ສາມາດປ່ຽນລະຫັດຜ່ານໄດ້"
 ],
 "Failed to enable $0 in firewalld": [
  null,
  "ບໍ່ສາມາດເປີດໃຊ້ງານ $0 ໃນ firewalld ໄດ້"
 ],
 "Go to now": [
  null,
  "ໄປທີ່ປັດຈຸບັນ"
 ],
 "Handheld": [
  null,
  "ອຸປະກອນພົກພາ"
 ],
 "Hide confirmation password": [
  null,
  "ເຊື່ອງລະຫັດຜ່ານຢືນຢັນ"
 ],
 "Hide password": [
  null,
  "ເຊື່ອງລະຫັດຜ່ານ"
 ],
 "Host is unknown": [
  null,
  "ບໍ່ຮູ້ຈັກໂຮສຕ໌"
 ],
 "Host key is incorrect": [
  null,
  "ຄີຂອງໂຮສຕ໌ບໍ່ຖືກຕ້ອງ"
 ],
 "Hostkey does not match": [
  null,
  "ຄີຂອງໂຮສຕ໌ບໍ່ກົງກັນ"
 ],
 "Hostkey is unknown": [
  null,
  "ບໍ່ຮູ້ຈັກຄີຂອງໂຮສຕ໌"
 ],
 "If the fingerprint matches, click \"Accept key and log in\". Otherwise, do not log in and contact your administrator.": [
  null,
  "ຖ້າລາຍນິ້ວມືກົງກັນ, ກົດ \"ຍອມຮັບຄີ ແລະ ເຂົ້າສູ່ລະບົບ\". ຖ້າບໍ່ດັ່ງນັ້ນ, ຫ້າມເຂົ້າສູ່ລະບົບ ແລະ ຕິດຕໍ່ຜູ້ດູແລລະບົບຂອງເຈົ້າ."
 ],
 "If the fingerprint matches, click 'Trust and add host'. Otherwise, do not connect and contact your administrator.": [
  null,
  "ຖ້າລາຍນິ້ວມືກົງກັນ, ກົດ 'ເຊື່ອຖື ແລະ ເພີ່ມໂຮສຕ໌'. ຖ້າບໍ່ດັ່ງນັ້ນ, ຫ້າມເຊື່ອມຕໍ່ ແລະ ຕິດຕໍ່ຜູ້ດູແລລະບົບຂອງເຈົ້າ."
 ],
 "Install": [
  null,
  "ຕິດຕັ້ງ"
 ],
 "Install software": [
  null,
  "ຕິດຕັ້ງຊອບແວ"
 ],
 "Install the cockpit-system package (and optionally other cockpit packages) on $0 to enable web console access.": [
  null,
  "ຕິດຕັ້ງແພັກເກດ cockpit-system (ແລະ ແພັກເກດ cockpit ອື່ນໆ ຖ້າຕ້ອງການ) ໃນ $0 ເພື່ອເປີດໃຊ້ງານການເຂົ້າເຖິງເວັບຄອນໂຊນ."
 ],
 "Installing $0": [
  null,
  "ກຳລັງຕິດຕັ້ງ $0"
 ],
 "Internal error": [
  null,
  "ຂໍ້ຜິດພາດພາຍໃນ"
 ],
 "Internal error: Invalid challenge header": [
  null,
  "ຂໍ້ຜິດພາດພາຍໃນ: ຫົວຂໍ້ challenge ບໍ່ຖືກຕ້ອງ"
 ],
 "Internal protocol error": [
  null,
  "ຂໍ້ຜິດພາດຂອງໂປຣໂຕຄໍພາຍໃນ"
 ],
 "Invalid date format": [
  null,
  "ຮູບແບບວັນທີບໍ່ຖືກຕ້ອງ"
 ],
 "Invalid date format and invalid time format": [
  null,
  "ຮູບແບບວັນທີ ແລະ ຮູບແບບເວລາບໍ່ຖືກຕ້ອງ"
 ],
 "Invalid file permissions": [
  null,
  "ການອະນຸຍາດໄຟລ໌ບໍ່ຖືກຕ້ອງ"
 ],
 "Invalid time format": [
  null,
  "ຮູບແບບເວລາບໍ່ຖືກຕ້ອງ"
 ],
 "Invalid timezone": [
  null,
  "ເຂດເວລາບໍ່ຖືກຕ້ອງ"
 ],
 "IoT gateway": [
  null,
  "IoT gateway"
 ],
 "Kernel dump": [
  null,
  "Kernel dump"
 ],
 "Key password": [
  null,
  "ລະຫັດຜ່ານຄີ"
 ],
 "Laptop": [
  null,
  "ແລັບທອບ"
 ],
 "Learn more": [
  null,
  "ຮຽນຮູ້ເພີ່ມເຕີມ"
 ],
 "Limit access": [
  null,
  "ຈຳກັດການເຂົ້າເຖິງ"
 ],
 "Limited access": [
  null,
  "ການເຂົ້າເຖິງແບບຈຳກັດ"
 ],
 "Limited access mode restricts administrative privileges. Some parts of the web console will have reduced functionality.": [
  null,
  "ໂໝດການເຂົ້າເຖິງແບບຈຳກັດຈະຈຳກັດສິດຜູ້ດູແລລະບົບ. ບາງສ່ວນຂອງເວັບຄອນໂຊນຈະມີຟັງຊັນການເຮັດວຽກທີ່ຫຼຸດລົງ."
 ],
 "Loading system modifications...": [
  null,
  "ກຳລັງໂຫຼດການປ່ຽນແປງຂອງລະບົບ..."
 ],
 "Log in": [
  null,
  "ເຂົ້າສູ່ລະບົບ"
 ],
 "Log in to $0": [
  null,
  "ເຂົ້າສູ່ລະບົບ $0"
 ],
 "Log in with your server user account.": [
  null,
  "ເຂົ້າສູ່ລະບົບດ້ວຍບັນຊີຜູ້ໃຊ້ເຊີບເວີຂອງເຈົ້າ."
 ],
 "Log messages": [
  null,
  "ຂໍ້ຄວາມລັອກ"
 ],
 "Login": [
  null,
  "ການເຂົ້າສູ່ລະບົບ"
 ],
 "Login again": [
  null,
  "ເຂົ້າສູ່ລະບົບອີກຄັ້ງ"
 ],
 "Login failed": [
  null,
  "ເຂົ້າສູ່ລະບົບບໍ່ສຳເລັດ"
 ],
 "Logout successful": [
  null,
  "ອອກຈາກລະບົບສຳເລັດແລ້ວ"
 ],
 "Low profile desktop": [
  null,
  "Low profile desktop"
 ],
 "Lunch box": [
  null,
  "Lunch box"
 ],
 "Main server chassis": [
  null,
  "Main server chassis"
 ],
 "Manage storage": [
  null,
  "ຈັດການບ່ອນຈັດເກັບຂໍ້ມູນ"
 ],
 "Manually": [
  null,
  "ດ້ວຍຕົນເອງ"
 ],
 "Message to logged in users": [
  null,
  "ຂໍ້ຄວາມເຖິງຜູ້ໃຊ້ທີ່ເຂົ້າສູ່ລະບົບຢູ່"
 ],
 "Method": [
  null,
  "ວິທີການ"
 ],
 "Mini PC": [
  null,
  "ມິນິພີຊີ (Mini PC)"
 ],
 "Mini tower": [
  null,
  "ມິນິທາວເວີ (Mini tower)"
 ],
 "Multi-system chassis": [
  null,
  "ໂຄງເຄື່ອງແບບຫຼາຍລະບົບ"
 ],
 "NTP server": [
  null,
  "ເຊີບເວີ NTP"
 ],
 "Need at least one NTP server": [
  null,
  "ຕ້ອງການເຊີບເວີ NTP ຢ່າງໜ້ອຍໜຶ່ງຕົວ"
 ],
 "Networking": [
  null,
  "ລະບົບເຄືອຂ່າຍ"
 ],
 "New host": [
  null,
  "ໂຮສຕ໌ (host) ໃໝ່"
 ],
 "New password was not accepted": [
  null,
  "ລະຫັດຜ່ານໃໝ່ບໍ່ຖືກຍອມຮັບ"
 ],
 "No delay": [
  null,
  "ບໍ່ມີການຊັກຊ້າ"
 ],
 "No methods to gain administrative access are available (sudo -A, pkexec).": [
  null,
  "ບໍ່ມີວິທີການເຂົ້າເຖິງສິດຜູ້ດູແລລະບົບ (sudo -A, pkexec)."
 ],
 "No results found": [
  null,
  "ບໍ່ພົບຜົນລັບ"
 ],
 "No such file or directory": [
  null,
  "ບໍ່ມີໄຟລ໌ ຫຼື ໄດເຣັກທໍຣີນີ້"
 ],
 "No system modifications": [
  null,
  "ບໍ່ມີການແກ້ໄຂລະບົບ"
 ],
 "Not a valid private key": [
  null,
  "ບໍ່ແມ່ນໄພຣເວດຄີ (private key) ທີ່ຖືກຕ້ອງ"
 ],
 "Not permitted to perform this action.": [
  null,
  "ບໍ່ໄດ້ຮັບອະນຸຍາດໃຫ້ເຮັດການນີ້."
 ],
 "Not synchronized": [
  null,
  "ບໍ່ໄດ້ຊິງໂຄຣໄນຊ໌"
 ],
 "Notebook": [
  null,
  "ໂນ້ດບຸກ"
 ],
 "Occurrences": [
  null,
  "ຈຳນວນການເກີດຂຶ້ນ"
 ],
 "Ok": [
  null,
  "ຕົກລົງ"
 ],
 "Old password not accepted": [
  null,
  "ລະຫັດຜ່ານເກົ່າບໍ່ຖືກຍອມຮັບ"
 ],
 "Once Cockpit is installed, enable it with \"systemctl enable --now cockpit.socket\".": [
  null,
  "ເມື່ອຕິດຕັ້ງ Cockpit ແລ້ວ, ໃຫ້ເປີດໃຊ້ງານດ້ວຍຄຳສັ່ງ \"systemctl enable --now cockpit.socket\"."
 ],
 "Or use a bundled browser": [
  null,
  "ຫຼື ໃຊ້ບຣາວເຊີທີ່ມາພ້ອມກັນ"
 ],
 "Other": [
  null,
  "ອື່ນໆ"
 ],
 "Other options": [
  null,
  "ຕົວເລືອກອື່ນໆ"
 ],
 "PackageKit crashed": [
  null,
  "PackageKit ຂັດຂ້ອງ"
 ],
 "Packageless session unavailable": [
  null,
  "ເຊສຊັນແບບບໍ່ມີແພັກເກດບໍ່ພ້ອມໃຊ້ງານ"
 ],
 "Password": [
  null,
  "ລະຫັດຜ່ານ"
 ],
 "Password is not acceptable": [
  null,
  "ລະຫັດຜ່ານບໍ່ຖືກຍອມຮັບ"
 ],
 "Password is too weak": [
  null,
  "ລະຫັດຜ່ານອ່ອນເກີນໄປ"
 ],
 "Password not accepted": [
  null,
  "ລະຫັດຜ່ານບໍ່ຖືກຍອມຮັບ"
 ],
 "Paste": [
  null,
  "ວາງ (Paste)"
 ],
 "Paste error": [
  null,
  "ເກີດຄວາມຜິດພາດໃນການວາງ"
 ],
 "Path to file": [
  null,
  "ເສັ້ນທາງໄປຫາໄຟລ໌"
 ],
 "Peripheral chassis": [
  null,
  "ໂຄງເຄື່ອງອຸປະກອນຕໍ່ພ່ວງ"
 ],
 "Permission denied": [
  null,
  "ການອະນຸຍາດຖືກປະຕິເສດ"
 ],
 "Pick date": [
  null,
  "ເລືອກວັນທີ"
 ],
 "Pizza box": [
  null,
  "ພິດຊ່າບັອກ (Pizza box)"
 ],
 "Please authenticate to gain administrative access": [
  null,
  "ກະລຸນາຢືນຢັນຕົວຕົນເພື່ອເຂົ້າເຖິງສິດຜູ້ດູແລລະບົບ"
 ],
 "Please enable JavaScript to use the Web Console.": [
  null,
  "ກະລຸນາເປີດໃຊ້ JavaScript ເພື່ອໃຊ້ງານ Web Console."
 ],
 "Please specify the host to connect to": [
  null,
  "ກະລຸນາລະບຸໂຮສຕ໌ທີ່ຈະເຊື່ອມຕໍ່"
 ],
 "Portable": [
  null,
  "ພົກພາໄດ້"
 ],
 "Present": [
  null,
  "ມີຢູ່"
 ],
 "Problem becoming administrator": [
  null,
  "ມີບັນຫາໃນການກາຍເປັນຜູ້ດູແລລະບົບ"
 ],
 "Prompting via ssh-add timed out": [
  null,
  "ການຖາມຜ່ານ ssh-add ໝົດເວລາ"
 ],
 "Prompting via ssh-keygen timed out": [
  null,
  "ການຖາມຜ່ານ ssh-keygen ໝົດເວລາ"
 ],
 "RAID chassis": [
  null,
  "ໂຄງເຄື່ອງ RAID"
 ],
 "Rack mount chassis": [
  null,
  "ໂຄງເຄື່ອງແບບຕິດຕັ້ງໃນແຣັກ"
 ],
 "Reboot": [
  null,
  "ບູດເຄື່ອງໃໝ່"
 ],
 "Recent hosts": [
  null,
  "ໂຮສຕ໌ທີ່ໃຊ້ບໍ່ດົນມານີ້"
 ],
 "Refusing to connect": [
  null,
  "ປະຕິເສດການເຊື່ອມຕໍ່"
 ],
 "Removals:": [
  null,
  "ການລຶບອອກ:"
 ],
 "Remove host": [
  null,
  "ລຶບໂຮສຕ໌ອອກ"
 ],
 "Removing $0": [
  null,
  "ກຳລັງລຶບ $0 ອອກ"
 ],
 "Row expansion": [
  null,
  "ການຂະຫຍາຍແຖວ"
 ],
 "Row select": [
  null,
  "ເລືອກແຖວ"
 ],
 "Run this command over a trusted network or physically on the remote machine:": [
  null,
  "ຣັນຄຳສັ່ງນີ້ຜ່ານເຄືອຂ່າຍທີ່ເຊື່ອຖືໄດ້ ຫຼື ຣັນຢູ່ເຄື່ອງປາຍທາງໂດຍກົງ:"
 ],
 "SELinux": [
  null,
  "SELinux"
 ],
 "SSH key": [
  null,
  "ຄີ SSH"
 ],
 "SSH key login": [
  null,
  "ການເຂົ້າສູ່ລະບົບດ້ວຍຄີ SSH"
 ],
 "Sealed-case PC": [
  null,
  "ພີຊີແບບກ່ອງປິດ (Sealed-case PC)"
 ],
 "Security Enhanced Linux configuration and troubleshooting": [
  null,
  "ການຕັ້ງຄ່າ ແລະ ການແກ້ໄຂບັນຫາ Security Enhanced Linux"
 ],
 "Select an option": [
  null,
  "ເລືອກຕົວເລືອກ"
 ],
 "Server": [
  null,
  "ເຊີເວີ"
 ],
 "Server closed connection": [
  null,
  "ເຊີເວີປິດການເຊື່ອມຕໍ່"
 ],
 "Server has closed the connection.": [
  null,
  "ເຊີເວີໄດ້ປິດການເຊື່ອມຕໍ່ແລ້ວ."
 ],
 "Set time": [
  null,
  "ຕັ້ງເວລາ"
 ],
 "Shell script": [
  null,
  "ສະຄຣິບເຊວ"
 ],
 "Shift+Insert": [
  null,
  "Shift+Insert"
 ],
 "Show confirmation password": [
  null,
  "ສະແດງລະຫັດຜ່ານຢືນຢັນ"
 ],
 "Show password": [
  null,
  "ສະແດງລະຫັດຜ່ານ"
 ],
 "Shut down": [
  null,
  "ປິດເຄື່ອງ"
 ],
 "Single rank": [
  null,
  "Single rank"
 ],
 "Space-saving computer": [
  null,
  "ຄອມພິວເຕີແບບປະຢັດພື້ນທີ່"
 ],
 "Specific time": [
  null,
  "ເວລາສະເພາະ"
 ],
 "Stick PC": [
  null,
  "Stick PC"
 ],
 "Storage": [
  null,
  "ບ່ອນຈັດເກັບຂໍ້ມູນ"
 ],
 "Strong password": [
  null,
  "ລະຫັດຜ່ານທີ່ແຂງແຮງ"
 ],
 "Sub-Chassis": [
  null,
  "Sub-Chassis"
 ],
 "Sub-Notebook": [
  null,
  "Sub-Notebook"
 ],
 "Switch to administrative access": [
  null,
  "ປ່ຽນເປັນການເຂົ້າເຖິງແບບຜູ້ດູແລລະບົບ"
 ],
 "Switch to limited access": [
  null,
  "ປ່ຽນເປັນການເຂົ້າເຖິງແບບຈຳກັດ"
 ],
 "Synchronized": [
  null,
  "ຊິງໂຄຣໄນຊ໌ແລ້ວ"
 ],
 "Synchronized with $0": [
  null,
  "ຊິງໂຄຣໄນຊ໌ກັບ $0 ແລ້ວ"
 ],
 "Synchronizing": [
  null,
  "ກຳລັງຊິງໂຄຣໄນຊ໌"
 ],
 "Tablet": [
  null,
  "ແທັບເລັດ"
 ],
 "The SSH key $0 of $1 on $2 will be added to the $3 file of $4 on $5.": [
  null,
  "ຄີ SSH $0 ຂອງ $1 ຢູ່ $2 ຈະຖືກເພີ່ມເຂົ້າໃນໄຟລ໌ $3 ຂອງ $4 ຢູ່ $5."
 ],
 "The SSH key $0 will be made available for the remainder of the session and will be available for login to other hosts as well.": [
  null,
  "ຄີ SSH $0 ຈະສາມາດໃຊ້ໄດ້ຕະຫຼອດວາລະການໃຊ້ງານທີ່ເຫຼືອ ແລະ ຈະສາມາດໃຊ້ເຂົ້າສູ່ລະບົບໂຮສຕ໌ອື່ນໆໄດ້ຄືກັນ."
 ],
 "The SSH key for logging in to $0 is protected by a password, and the host does not allow logging in with a password. Please provide the password of the key at $1.": [
  null,
  "ຄີ SSH ສຳລັບເຂົ້າສູ່ລະບົບ $0 ແມ່ນຖືກປ້ອງກັນດ້ວຍລະຫັດຜ່ານ, ແລະ ໂຮສຕ໌ບໍ່ອະນຸຍາດໃຫ້ເຂົ້າສູ່ລະບົບດ້ວຍລະຫັດຜ່ານ. ກະລຸນາລະບຸລະຫັດຜ່ານຂອງຄີຢູ່ $1."
 ],
 "The SSH key for logging in to $0 is protected. You can log in with either your login password or by providing the password of the key at $1.": [
  null,
  "ຄີ SSH ສຳລັບເຂົ້າສູ່ລະບົບ $0 ຖືກປ້ອງກັນໄວ້. ທ່ານສາມາດເຂົ້າສູ່ລະບົບດ້ວຍລະຫັດຜ່ານຂອງທ່ານ ຫຼື ລະບຸລະຫັດຜ່ານຂອງຄີຢູ່ $1."
 ],
 "The fingerprint should match:": [
  null,
  "ລາຍນິ້ວມື (Fingerprint) ຄວນຈະກົງກັບ:"
 ],
 "The key password can not be empty": [
  null,
  "ລະຫັດຜ່ານຂອງຄີບໍ່ສາມາດຫວ່າງເປົ່າໄດ້"
 ],
 "The key passwords do not match": [
  null,
  "ລະຫັດຜ່ານຂອງຄີບໍ່ກົງກັນ"
 ],
 "The logged in user is not permitted to view system modifications": [
  null,
  "ຜູ້ໃຊ້ທີ່ເຂົ້າສູ່ລະບົບບໍ່ໄດ້ຮັບອະນຸຍາດໃຫ້ເບິ່ງການປ່ຽນແປງລະບົບ"
 ],
 "The password can not be empty": [
  null,
  "ລະຫັດຜ່ານບໍ່ສາມາດຫວ່າງເປົ່າໄດ້"
 ],
 "The resulting fingerprint is fine to share via public methods, including email.": [
  null,
  "ລາຍນິ້ວມື (Fingerprint) ທີ່ໄດ້ສາມາດແບ່ງປັນຜ່ານຊ່ອງທາງສາທາລະນະໄດ້, ລວມທັງອີເມລ."
 ],
 "The resulting fingerprint is fine to share via public methods, including email. If you are asking someone else to do the verification for you, they can send the results using any method.": [
  null,
  "ລາຍນິ້ວມືທີ່ໄດ້ສາມາດແບ່ງປັນຜ່ານຊ່ອງທາງສາທາລະນະໄດ້, ລວມທັງອີເມລ. ຖ້າທ່ານໃຫ້ຄົນອື່ນກວດສອບໃຫ້, ເຂົາເຈົ້າສາມາດສົ່ງຜົນການກວດສອບໃຫ້ທ່ານດ້ວຍວິທີໃດກໍໄດ້."
 ],
 "The server refused to authenticate '$0' using password authentication, and no other supported authentication methods are available.": [
  null,
  "ເຊີເວີປະຕິເສດການຢືນຢັນຕົວຕົນຂອງ '$0' ດ້ວຍລະຫັດຜ່ານ, ແລະ ບໍ່ມີວິທີຢືນຢັນຕົວຕົນອື່ນທີ່ຮອງຮັບ."
 ],
 "The server refused to authenticate using any supported methods.": [
  null,
  "ເຊີເວີປະຕິເສດການຢືນຢັນຕົວຕົນດ້ວຍທຸກວິທີທີ່ຮອງຮັບ."
 ],
 "The web browser configuration prevents Cockpit from running (inaccessible $0)": [
  null,
  "ການຕັ້ງຄ່າເວັບບຣາວເຊີປ້ອງກັນບໍ່ໃຫ້ Cockpit ເຮັດວຽກໄດ້ (ບໍ່ສາມາດເຂົ້າເຖິງ $0)"
 ],
 "This tool configures the SELinux policy and can help with understanding and resolving policy violations.": [
  null,
  "ເຄື່ອງມືນີ້ໃຊ້ຕັ້ງຄ່ານະໂຍບາຍ SELinux ແລະ ສາມາດຊ່ວຍໃນການເຂົ້າໃຈ ແລະ ແກ້ໄຂການລະເມີດນະໂຍບາຍໄດ້."
 ],
 "This tool configures the system to write kernel crash dumps. It supports the \"local\" (disk), \"ssh\", and \"nfs\" dump targets.": [
  null,
  "ເຄື່ອງມືນີ້ໃຊ້ຕັ້ງຄ່າລະບົບເພື່ອບັນທຶກ kernel crash dumps. ມັນຮອງຮັບເປົ້າໝາຍການເກັບແບບ \"local\" (ດິດ), \"ssh\", ແລະ \"nfs\"."
 ],
 "This tool generates an archive of configuration and diagnostic information from the running system. The archive may be stored locally or centrally for recording or tracking purposes or may be sent to technical support representatives, developers or system administrators to assist with technical fault-finding and debugging.": [
  null,
  "ເຄື່ອງມືນີ້ໃຊ້ສ້າງໄຟລ໌ເກັບຂໍ້ມູນການຕັ້ງຄ່າ ແລະ ຂໍ້ມູນການວິເຄາະຈາກລະບົບທີ່ກຳລັງເຮັດວຽກຢູ່. ຂໍ້ມູນເຫຼົ່ານີ້ອາດຖືກເກັບໄວ້ໃນເຄື່ອງ ຫຼື ສ່ວນກາງເພື່ອຈຸດປະສົງໃນການບັນທຶກ ຫຼື ຕິດຕາມ, ຫຼື ສົ່ງໃຫ້ຝ່າຍຊ່ວຍເຫຼືອທາງເຕັກນິກ, ນັກພັດທະນາ ຫຼື ຜູ້ດູແລລະບົບເພື່ອຊ່ວຍໃນການແກ້ໄຂບັນຫາ ແລະ ດີບັກ (debug)."
 ],
 "This tool manages local storage, such as filesystems, LVM2 volume groups, and NFS mounts.": [
  null,
  "ເຄື່ອງມືນີ້ໃຊ້ຈັດການບ່ອນຈັດເກັບຂໍ້ມູນພາຍໃນເຄື່ອງ ເຊັ່ນ ລະບົບໄຟລ໌, LVM2 volume groups, ແລະ ການຕິດຕັ້ງ NFS."
 ],
 "This tool manages networking such as bonds, bridges, teams, VLANs and firewalls using NetworkManager and Firewalld. NetworkManager is incompatible with Ubuntu's default systemd-networkd and Debian's ifupdown scripts.": [
  null,
  "ເຄື່ອງມືນີ້ໃຊ້ຈັດການເຄືອຂ່າຍ ເຊັ່ນ bonds, bridges, teams, VLANs ແລະ ໄຟວໍ (firewalls) ໂດຍໃຊ້ NetworkManager ແລະ Firewalld."
 ],
 "This web browser is too old to run the Web Console (missing $0)": [
  null,
  "ເວັບບຣາວເຊີນີ້ເກົ່າເກີນໄປທີ່ຈະໃຊ້ Web Console ໄດ້ (ຂາດ $0)"
 ],
 "Time zone": [
  null,
  "ເຂດເວລາ"
 ],
 "To ensure that your connection is not intercepted by a malicious third-party, please verify the host key fingerprint:": [
  null,
  "ເພື່ອໃຫ້ແນ່ໃຈວ່າການເຊື່ອມຕໍ່ຂອງທ່ານບໍ່ຖືກດັກຟັງໂດຍບຸກຄົນທີສາມ, ກະລຸນາກວດສອບລາຍນິ້ວມືຂອງຄີໂຮສຕ໌:"
 ],
 "To verify a fingerprint, run the following on $0 while physically sitting at the machine or through a trusted network:": [
  null,
  "ເພື່ອການກວດສອບລາຍນິ້ວມື, ໃຫ້ຮັນຄຳສັ່ງຕໍ່ໄປນີ້ໃນ $0 ໃນຂະນະທີ່ຢູ່ໜ້າເຄື່ອງ ຫຼື ຜ່ານເຄືອຂ່າຍທີ່ໜ້າເຊື່ອຖື:"
 ],
 "Toggle date picker": [
  null,
  "ເປີດ-ປິດ ຕົວເລືອກວັນທີ"
 ],
 "Too much data": [
  null,
  "ຂໍ້ມູນຫຼາຍເກີນໄປ"
 ],
 "Total size: $0": [
  null,
  "ຂະໜາດທັງໝົດ: $0"
 ],
 "Tower": [
  null,
  "ທາວເວີ (Tower)"
 ],
 "Trust and add host": [
  null,
  "ເຊື່ອຖື ແລະ ເພີ່ມໂຮສຕ໌"
 ],
 "Try again": [
  null,
  "ລອງໃໝ່ອີກຄັ້ງ"
 ],
 "Trying to synchronize with $0": [
  null,
  "ກຳລັງພະຍາຍາມຊິງໂຄຣໄນຊ໌ກັບ $0"
 ],
 "Turn on administrative access": [
  null,
  "ເປີດການເຂົ້າເຖິງແບບຜູ້ດູແລລະບົບ"
 ],
 "Unable to connect to that address": [
  null,
  "ບໍ່ສາມາດເຊື່ອມຕໍ່ຫາທີ່ຢູ່ນັ້ນໄດ້"
 ],
 "Unable to log in to $0 using SSH key authentication. Please provide the password.": [
  null,
  "ບໍ່ສາມາດເຂົ້າສູ່ລະບົບ $0 ດ້ວຍການຢືນຢັນຄີ SSH ໄດ້. ກະລຸນາລະບຸລະຫັດຜ່ານ."
 ],
 "Unable to log in to $0. The host does not accept password login or any of your SSH keys.": [
  null,
  "ບໍ່ສາມາດເຂົ້າສູ່ລະບົບ $0 ໄດ້. ໂຮສຕ໌ບໍ່ຍອມຮັບການເຂົ້າລະບົບດ້ວຍລະຫັດຜ່ານ ຫຼື ຄີ SSH ໃດໆຂອງທ່ານ."
 ],
 "Unknown": [
  null,
  "ບໍ່ຮູ້ຈັກ"
 ],
 "Unknown host: $0": [
  null,
  "ບໍ່ຮູ້ຈັກໂຮສຕ໌: $0"
 ],
 "Unsupported shell. Check the journal for details.": [
  null,
  "ເຊວ (shell) ທີ່ບໍ່ຮອງຮັບ. ກວດສອບລາຍລະອຽດໃນ journal."
 ],
 "Untrusted host": [
  null,
  "ໂຮສຕ໌ທີ່ບໍ່ໜ້າເຊື່ອຖື"
 ],
 "User name": [
  null,
  "ຊື່ຜູ້ໃຊ້"
 ],
 "User name cannot be empty": [
  null,
  "ຊື່ຜູ້ໃຊ້ບໍ່ສາມາດຫວ່າງເປົ່າໄດ້"
 ],
 "Validating authentication token": [
  null,
  "ກຳລັງກວດສອບຄວາມຖືກຕ້ອງຂອງໂທເຄັນຢືນຢັນຕົວຕົນ"
 ],
 "Verify fingerprint": [
  null,
  "ກວດສອບລາຍນິ້ວມື"
 ],
 "View all logs": [
  null,
  "ເບິ່ງບັນທຶກທັງໝົດ"
 ],
 "View automation script": [
  null,
  "ເບິ່ງສະຄຣິບອັດຕະໂນມັດ"
 ],
 "Visit firewall": [
  null,
  "ໄປທີ່ໄຟວໍ"
 ],
 "Waiting for other software management operations to finish": [
  null,
  "ກຳລັງລໍຖ້າໃຫ້ການຈັດການຊອບແວອື່ນໆເຮັດວຽກໃຫ້ສຳເລັດ"
 ],
 "Weak password": [
  null,
  "ລະຫັດຜ່ານທີ່ບໍ່ປອດໄພ"
 ],
 "Web Console for Linux servers": [
  null,
  "Web Console ສຳລັບ Linux ເຊີເວີ"
 ],
 "Wrong user name or password": [
  null,
  "ຊື່ຜູ້ໃຊ້ ຫຼື ລະຫັດຜ່ານບໍ່ຖືກຕ້ອງ"
 ],
 "You are connecting to $0 for the first time.": [
  null,
  "ທ່ານກຳລັງເຊື່ອມຕໍ່ຫາ $0 ເປັນຄັ້ງທຳອິດ."
 ],
 "You now have administrative access.": [
  null,
  "ດຽວນີ້ທ່ານມີສິດເຂົ້າເຖິງແບບຜູ້ດູແລລະບົບແລ້ວ."
 ],
 "Your browser does not allow paste from the context menu. You can use Shift+Insert.": [
  null,
  "ບຣາວເຊີຂອງທ່ານບໍ່ອະນຸຍາດໃຫ້ວາງຂໍ້ມູນຈາກເມນູຄລິກຂວາ. ທ່ານສາມາດໃຊ້ Shift+Insert ແທນ."
 ],
 "Your browser will remember your access level across sessions.": [
  null,
  "ບຣາວເຊີຂອງທ່ານຈະຈົດຈຳລະດັບການເຂົ້າເຖິງຂອງທ່ານໄວ້."
 ],
 "Your session has been terminated.": [
  null,
  "ວາລະການໃຊ້ງານຂອງທ່ານຖືກສິ້ນສຸດແລ້ວ."
 ],
 "Your session has expired. Please log in again.": [
  null,
  "ວາລະການໃຊ້ງານຂອງທ່ານໝົດອາຍຸແລ້ວ. ກະລຸນາເຂົ້າສູ່ລະບົບໃໝ່."
 ],
 "Zone": [
  null,
  "ໂຊນ"
 ],
 "[binary data]": [
  null,
  "[ຂໍ້ມູນໄບນາຣີ]"
 ],
 "[no data]": [
  null,
  "[ບໍ່ມີຂໍ້ມູນ]"
 ],
 "in less than a minute": [
  null,
  "ພາຍໃນບໍ່ຮອດໜຶ່ງນາທີ"
 ],
 "less than a minute ago": [
  null,
  "ບໍ່ຮອດໜຶ່ງນາທີກ່ອນ"
 ],
 "password quality": [
  null,
  "ຄຸນນະພາບລະຫັດຜ່ານ"
 ],
 "show less": [
  null,
  "ສະແດງໜ້ອຍລົງ"
 ],
 "show more": [
  null,
  "ສະແດງເພີ່ມເຕີມ"
 ]
};
